Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Simple Workflow Service.

Actions, resources, and condition keys for Amazon Simple Workflow Service - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Simple Workflow Service

Amazon Simple Workflow Service (service prefix: `swf` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Simple Workflow Service
- Resource types defined by Amazon Simple Workflow Service
- Condition keys for Amazon Simple Workflow Service

## Actions defined by Amazon Simple Workflow Service

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelTimer | Grants permission to cancel a previously started timer and record a TimerCanceled event in the history | Write | domain* |  |
CancelWorkflowExecution | Grants permission to close the workflow execution and record a WorkflowExecutionCanceled event in the history | Write | domain* |  |
CompleteWorkflowExecution | Grants permission to close the workflow execution and record a WorkflowExecutionCompleted event in the history | Write | domain* |  |
ContinueAsNewWorkflowExecution | Grants permission to close the workflow execution and start a new workflow execution of the same type using the same workflow ID and a unique run Id | Write | domain* |  |
CountClosedWorkflowExecutions | Grants permission to return the number of closed workflow executions within the given domain that meet the specified filtering criteria | Read | domain* |  |
| swf:tagFilter.tag swf:typeFilter.name swf:typeFilter.version |
CountOpenWorkflowExecutions | Grants permission to return the number of open workflow executions within the given domain that meet the specified filtering criteria | Read | domain* |  |
| swf:tagFilter.tag swf:typeFilter.name swf:typeFilter.version |
CountPendingActivityTasks | Grants permission to return the estimated number of activity tasks in the specified task list | Read | domain* |  |
| swf:taskList.name |
CountPendingDecisionTasks | Grants permission to return the estimated number of decision tasks in the specified task list | Read | domain* |  |
| swf:taskList.name |
DeprecateActivityType | Grants permission to deprecate the specified activity type | Write | domain* |  |
| swf:activityType.name swf:activityType.version |
DeprecateDomain | Grants permission to deprecate the specified domain | Write | domain* |  |
DeprecateWorkflowType | Grants permission to deprecate the specified workflow type | Write | domain* |  |
| swf:workflowType.name swf:workflowType.version |
DescribeActivityType | Grants permission to return information about the specified activity type | Read | domain* |  |
| swf:activityType.name swf:activityType.version |
DescribeDomain | Grants permission to return information about the specified domain, including its description and status | Read | domain* |  |
DescribeWorkflowExecution | Grants permission to return information about the specified workflow execution including its type and some statistics | Read | domain* |  |
DescribeWorkflowType | Grants permission to return information about the specified workflow type | Read | domain* |  |
| swf:workflowType.name swf:workflowType.version |
FailWorkflowExecution | Grants permission to close the workflow execution and record a WorkflowExecutionFailed event in the history | Write | domain* |  |
GetWorkflowExecutionHistory | Grants permission to return the history of the specified workflow execution | Read | domain* |  |
ListActivityTypes | Grants permission to return information about all activities registered in the specified domain that match the specified name and registration status | List | domain* |  |
ListClosedWorkflowExecutions | Grants permission to return a list of closed workflow executions in the specified domain that meet the filtering criteria | List | domain* |  |
| swf:tagFilter.tag swf:typeFilter.name swf:typeFilter.version |
ListDomains | Grants permission to return the list of domains registered in the account | List |  |  |
ListOpenWorkflowExecutions | Grants permission to return a list of open workflow executions in the specified domain that meet the filtering criteria | List | domain* |  |
| swf:tagFilter.tag swf:typeFilter.name swf:typeFilter.version |
ListTagsForResource | Grants permission to list tags for an AWS SWF resource | List | domain |  |
ListWorkflowTypes | Grants permission to return information about workflow types in the specified domain | List | domain* |  |
PollForActivityTask | Grants permission to workers to get an ActivityTask from the specified activity taskList | Write | domain* |  |
| swf:taskList.name |
PollForDecisionTask | Grants permission to deciders to get a DecisionTask from the specified decision taskList | Write | domain* |  |
| swf:taskList.name |
RecordActivityTaskHeartbeat | Grants permission to workers to report to the service that the ActivityTask represented by the specified taskToken is still making progress | Write | domain* |  |
RecordMarker | Grants permission to record a MarkerRecorded event in the history | Write | domain* |  |
RegisterActivityType | Grants permission to register a new activity type along with its configuration settings in the specified domain | Write | domain* |  |
| swf:defaultTaskList.name swf:name swf:version |
RegisterDomain | Grants permission to register a new domain | Write |  | aws:TagKeys aws:RequestTag/${TagKey} |
RegisterWorkflowType | Grants permission to register a new workflow type and its configuration settings in the specified domain | Write | domain* |  |
| swf:defaultTaskList.name swf:name swf:version |
RequestCancelActivityTask | Grants permission to attempt to cancel a previously scheduled activity task | Write | domain* |  |
RequestCancelExternalWorkflowExecution | Grants permission to request that a request be made to cancel the specified external workflow execution | Write | domain* |  |
RequestCancelWorkflowExecution | Grants permission to record a WorkflowExecutionCancelRequested event in the currently running workflow execution identified by the given domain, workflowId, and runId | Write | domain* |  |
RespondActivityTaskCanceled | Grants permission to workers to tell the service that the ActivityTask identified by the taskToken was successfully canceled | Write | domain* |  |
RespondActivityTaskCompleted | Grants permission to workers to tell the service that the ActivityTask identified by the taskToken completed successfully with a result (if provided) | Write | domain* |  |
| swf:activityType.name swf:activityType.version swf:tagList.member.0 swf:tagList.member.1 swf:tagList.member.2 swf:tagList.member.3 swf:tagList.member.4 swf:taskList.name swf:workflowType.name swf:workflowType.version |
RespondActivityTaskFailed | Grants permission to workers to tell the service that the ActivityTask identified by the taskToken has failed with reason (if specified) | Write | domain* |  |
RespondDecisionTaskCompleted | Grants permission to deciders to tell the service that the DecisionTask identified by the taskToken has successfully completed | Write | domain* |  |
ScheduleActivityTask | Grants permission to schedule an activity task | Write | domain* |  |
SignalExternalWorkflowExecution | Grants permission to request a signal to be delivered to the specified external workflow execution and records | Write | domain* |  |
SignalWorkflowExecution | Grants permission to record a WorkflowExecutionSignaled event in the workflow execution history and create a decision task for the workflow execution identified by the given domain, workflowId and runId | Write | domain* |  |
StartChildWorkflowExecution | Grants permission to request that a child workflow execution be started | Write | domain* |  |
StartTimer | Grants permission to start a timer for a workflow execution | Write | domain* |  |
StartWorkflowExecution | Grants permission to start an execution of the workflow type in the specified domain using the provided workflowId and input data | Write | domain* |  |
| swf:tagList.member.0 swf:tagList.member.1 swf:tagList.member.2 swf:tagList.member.3 swf:tagList.member.4 swf:taskList.name swf:workflowType.name swf:workflowType.version |
TagResource | Grants permission to tag an AWS SWF resource | Tagging | domain |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
TerminateWorkflowExecution | Grants permission to record a WorkflowExecutionTerminated event and force closure of the workflow execution identified by the given domain, runId, and workflowId | Write | domain* |  |
UndeprecateActivityType | Grants permission to undeprecate a previously deprecated activity type | Write | domain* |  |
| swf:activityType.name swf:activityType.version |
UndeprecateDomain | Grants permission to undeprecate a previously deprecated domain | Write | domain* |  |
UndeprecateWorkflowType | Grants permission to undeprecate a previously deprecated workflow type | Write | domain* |  |
| swf:workflowType.name swf:workflowType.version |
UntagResource | Grants permission to remove a tag from an AWS SWF resource | Tagging | domain |  |
| aws:TagKeys |

## Resource types defined by Amazon Simple Workflow Service

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
domain | `arn:$ { Partition}:swf::$ { Account}:/domain/$ { DomainName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Simple Workflow Service

Amazon Simple Workflow Service defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by tag of the request | String
aws:ResourceTag/${TagKey} | Filters access by tag of the resource | String
aws:TagKeys | Filters access by tag of the key | ArrayOfString
swf:activityType.name | Filters access by the name of the activity type | String
swf:activityType.version | Filters access by the version of the activity type | String
swf:defaultTaskList.name | Filters access by the name of the default task list | String
swf:name | Filters access by the name of activities or workflows | String
swf:tagFilter.tag | Filters access by the value of tagFilter.tag | String
swf:tagList.member.0 | Filters access by the specified tag | String
swf:tagList.member.1 | Filters access by the specified tag | String
swf:tagList.member.2 | Filters access by the specified tag | String
swf:tagList.member.3 | Filters access by the specified tag | String
swf:tagList.member.4 | Filters access by the specified tag | String
swf:taskList.name | Filters access by the name of the tasklist | String
swf:typeFilter.name | Filters access by the name of the type filter | String
swf:typeFilter.version | Filters access by the version of the type filter | String
swf:version | Filters access by the version of activities or workflows | String
swf:workflowType.name | Filters access by the name of the workflow type | String
swf:workflowType.version | Filters access by the version of the workflow type | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.